@@ -40,7 +40,9 @@ Jason Antman <jason@jasonantman.com> <http://www.jasonantman.com>
 import sys
 import pytest
 from awslimitchecker.services.ses import _SesService
-from botocore.exceptions import ClientError, EndpointConnectionError
+from botocore.exceptions import (
+    ClientError, EndpointConnectionError, ConnectTimeoutError
+)
 
 # https://code.google.com/p/mock/issues/detail?id=249
 # py>=3.4 should use unittest.mock not the mock package on pypi
@@ -106,8 +108,9 @@ class Test_SesService(object):
         assert cls._have_usage is True
         assert mock_conn.mock_calls == [call.get_send_quota()]
         assert len(cls.limits['Daily sending quota'].get_current_usage()) == 1
-        assert cls.limits['Daily sending quota'].get_current_usage()[
-                   0].get_value() == 122.0
+        assert cls.limits[
+            'Daily sending quota'
+        ].get_current_usage()[0].get_value() == 122.0
 
     def test_find_usage_invalid_region(self):
         def se_get():
@@ -171,6 +174,30 @@ class Test_SesService(object):
         assert mock_conn.mock_calls == [call.get_send_quota()]
         assert len(cls.limits['Daily sending quota'].get_current_usage()) == 0
 
+    def test_find_usage_invalid_region_connect_timeout(self):
+        ce = ConnectTimeoutError(endpoint_url='http://example.com')
+
+        def se_get():
+            raise ce
+
+        mock_conn = Mock()
+        mock_conn.get_send_quota.side_effect = se_get
+
+        with patch('%s.connect' % pb) as mock_connect:
+            with patch('%s.logger' % pbm) as mock_logger:
+                cls = _SesService(21, 43, {}, None)
+                cls.conn = mock_conn
+                assert cls._have_usage is False
+                cls.find_usage()
+        assert mock_connect.mock_calls == [call()]
+        assert cls._have_usage is False
+        assert mock_logger.mock_calls == [
+            call.debug('Checking usage for service %s', 'SES'),
+            call.warning('Skipping SES: %s', str(ce))
+        ]
+        assert mock_conn.mock_calls == [call.get_send_quota()]
+        assert len(cls.limits['Daily sending quota'].get_current_usage()) == 0
+
     def test_find_usage_invalid_region_503(self):
         resp = {
             'ResponseMetadata': {
@@ -312,6 +339,27 @@ class Test_SesService(object):
         ]
         assert cls.limits['Daily sending quota'].api_limit is None
 
+    def test_update_limits_from_api_invalid_region_connect_timeout(self):
+        ce = ConnectTimeoutError(endpoint_url='http://example.com')
+
+        def se_get():
+            raise ce
+
+        mock_conn = Mock()
+        mock_conn.get_send_quota.side_effect = se_get
+
+        with patch('%s.connect' % pb) as mock_connect:
+            with patch('%s.logger' % pbm) as mock_logger:
+                cls = _SesService(21, 43, {}, None)
+                cls.conn = mock_conn
+                cls._update_limits_from_api()
+        assert mock_connect.mock_calls == [call()]
+        assert mock_conn.mock_calls == [call.get_send_quota()]
+        assert mock_logger.mock_calls == [
+            call.warning('Skipping SES: %s', str(ce))
+        ]
+        assert cls.limits['Daily sending quota'].api_limit is None
+
     def test_update_limits_from_api_invalid_region_503(self):
         resp = {
             'ResponseMetadata': {
